# Table of Contents

- [response-status-codes](<./response-status-codes.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Response Status Codes](<./Response-Status-Codes.md>)
  - [Overview](<./Response-Status-Codes/Overview.md>)
  - [Success Codes (2xx)](<./Response-Status-Codes/Success-Codes-2xx.md>)
  - [Client-Side Error Codes (4xx)](<./Response-Status-Codes/Client-Side-Error-Codes-4xx.md>)
  - [Server-Side Error Codes (5xx)](<./Response-Status-Codes/Server-Side-Error-Codes-5xx.md>)
